@@ -1,5 +1,5 @@
 """
-TexProject
+TexPRoject
 
 Automatic LaTeX project management.
 
@@ -7,5 +7,5 @@ Automatic LaTeX project management.
 :license: MIT, see LICENSE for more details.
 """
 
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 __repo__ = "https://github.com/alexrutar/texproject"
